@@ -291,7 +291,12 @@ class SparkPipelineFrameworkTestRunner:
             lib_path: str = testable_folder[search_result_start_:].replace("/", ".")
             # load the transformer file (i.e., module)
             full_reference = lib_path + "." + transformer_file_name
-            my_class = ClassHelpers.get_first_class_in_file(full_reference)
+            try:
+                my_class = ClassHelpers.get_first_class_in_file(full_reference)
+            except ModuleNotFoundError:
+                # check if mapping_importer.py exists
+                full_reference = lib_path + "." + "mapping_importer"
+                my_class = ClassHelpers.get_first_class_in_file(full_reference)
 
         with ProgressLogger() as progress_logger:
             # now figure out the class_parameters to use when instantiating the class
